@@ -25,6 +25,7 @@ class EndpointData():
 			"cn-beijing-gov-1": "r-kvstore.aliyuncs.com",
 			"cn-shenzhen-su18-b01": "r-kvstore.aliyuncs.com",
 			"cn-beijing": "r-kvstore.aliyuncs.com",
+			"cn-wulanchabu": "r-kvstore.aliyuncs.com",
 			"cn-shanghai-inner": "r-kvstore.aliyuncs.com",
 			"cn-shenzhen-st4-d01": "r-kvstore.aliyuncs.com",
 			"cn-haidian-cm12-c01": "r-kvstore.aliyuncs.com",
@@ -36,6 +37,7 @@ class EndpointData():
 			"cn-qingdao-nebula": "r-kvstore.aliyuncs.com",
 			"cn-shanghai": "r-kvstore.aliyuncs.com",
 			"cn-shanghai-finance-1": "r-kvstore.aliyuncs.com",
+			"cn-heyuan": "r-kvstore.aliyuncs.com",
 			"cn-beijing-finance-pop": "r-kvstore.aliyuncs.com",
 			"cn-wuhan": "r-kvstore.aliyuncs.com",
 			"us-west-1": "r-kvstore.aliyuncs.com",
@@ -52,6 +54,7 @@ class EndpointData():
 			"cn-shenzhen-finance-1": "r-kvstore.aliyuncs.com",
 			"cn-hangzhou-internal-test-2": "r-kvstore.aliyuncs.com",
 			"cn-hangzhou-test-306": "r-kvstore.aliyuncs.com",
+			"cn-huhehaote-nebula-1": "r-kvstore.aliyuncs.com",
 			"cn-shanghai-et2-b01": "r-kvstore.aliyuncs.com",
 			"cn-hangzhou-finance": "r-kvstore.aliyuncs.com",
 			"ap-southeast-1": "r-kvstore.aliyuncs.com",
